@@ -2,7 +2,10 @@
 #!/usr/bin/env python
 
 import re
+import sys
 import enum
+from pathlib import Path
+sys.path.append(Path(__file__).parent.as_posix()) # https://stackoverflow.com/questions/16981921
 from constants import DATAFILE, USERFILE, URLREGX
 
 class State(enum.Enum):
@@ -72,7 +75,7 @@ class PersianEditor:
     __repr__ = __str__
 
     def _handle_urls(self, state):
-        """Removing URLs and putting them back at the end of process"""
+        """Removing URLs and putting them back at the end of the process"""
         if state == State.save:
             self.urls = re.findall(URLREGX, self.text, re.M)
             self.urls.sort(key=lambda x: len(x), reverse=True)
@@ -251,6 +254,8 @@ class PersianEditor:
             r'\1 ',
             self.text
         )
+        # special case for floating-point numbers like 12.7
+        self.text = re.sub(r'([\d])([.])\s([\d])', r'\1\2\3', self.text)
         self.text = re.sub(
             r'[ ‌ ]*((؟\s+!){1})[ ‌ ]*',
             r'؟! ',
@@ -261,6 +266,11 @@ class PersianEditor:
             r'\1:\2',
             self.text
         )
+        self.text = re.sub(
+            r'(\d+):\s+(\d+)',
+            r'\1:\2',
+            self.text
+        )
         # Fixes inside spacing for () [] {} "" «»
         self.text = re.sub(
             r'(\()\s*([^)]+?)\s*?(\))',
